copyWith abstract method

StorableModel copyWith()

Creates a new instance of the model with updated fields.

This method should return a copy of the current object with the ability to override specific fields.

Example:

final updatedModel = model.copyWith(name: "New Name");

Implementation

StorableModel copyWith();