service/treeCraft/tree_repository/src/model/tree_mappable library

Classes

TreeMappable<T, C>
An abstract class representing a mappable tree structure where each node has an identifier, a list of children nodes, and an optional data payload.