GenericTreeNode<T, C> class

Implemented types

Constructors

GenericTreeNode({required String id, T? data, List<TreeMappable<T, C>>? children})

Properties

children List<TreeMappable<T, C>>
no setteroverride
data → T?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
treeData → T?
Optional data associated with this node. It can be null if no data is set.
no setteroverride
treeId String
The unique identifier for this node.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited