service/searching/findElementWithMaxFrequency/find_element_with_max_frequency library
Functions
-
findElementWithMaxFrequency<
T> (List< T> list) → T - Returns the element with the highest frequency in the list. If multiple elements have the same max frequency, returns any one of them. Throws ArgumentError if the list is empty.
-
main(
) → void