service/searching/findMajorityElements/find_majority_elements library
Functions
-
findMajorityElements<
T> (List< T> list) → List<T> - Returns a list of elements that appear more than n/2 times in the list. For a single majority element, returns a list with one element. If no such element exists, returns an empty list.
-
main(
) → void