TreeTraversal<T, C> class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findBFS(TreeMappable<T, C> node, String searchId)
→ TreeMappable<T, C>?
-
Finds a node by ID using Breadth-First Search (BFS).
-
findDFS(TreeMappable<T, C> node, String searchId)
→ TreeMappable<T, C>?
-
Finds a node by ID using Depth-First Search (DFS).
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
visitBFS(TreeMappable<T, C> node, void visit(TreeMappable<T, C> node))
→ void
-
Visits each node using Breadth-First Search (BFS).
-
visitDFS(TreeMappable<T, C> node, void visit(TreeMappable<T, C> node))
→ void
-
Visits each node using Depth-First Search (DFS).